import { Pen } from "@meta2d/core";

export function monitorNoRoom(ctx: CanvasRenderingContext2D, pen: Pen): void {
  const radius = pen.calculative.borderRadius;
  const {
    x: rectX,
    y: rectY,
    width: rectWidth,
    height: rectHeight,
  } = pen.calculative.worldRect;

  ctx.save();

  // 条纹参数
  const stripeSpacing = 14; // 垂直方向间距
  const stripeColor = "#d4d8d7";
  const stripeAngle = 120; // 角度调整为120度

  // 1. 绘制灰色背景
  ctx.beginPath();
  ctx.roundRect(rectX, rectY, rectWidth, rectHeight, radius);
  ctx.fillStyle = "#f1f1f1";
  ctx.fill();

  // 2. 创建裁剪区域
  ctx.beginPath();
  ctx.roundRect(rectX, rectY, rectWidth, rectHeight, radius);
  ctx.clip();

  // 3. 计算斜线参数
  const angleRad = (stripeAngle * Math.PI) / 180;
  const slope = Math.tan(angleRad); // tan(120°) = -√3 ≈ -1.732

  // 计算实际步长（根据垂直间距换算）
  const bStep = Math.abs(stripeSpacing / Math.cos(angleRad)); // 保持步长为正数

  // 4. 动态计算绘制范围
  const diagonal = Math.hypot(rectWidth, rectHeight);
  const offset = diagonal * 2; // 扩展绘制范围的安全值

  // 计算截距范围（考虑坐标系方向和负斜率）
  const minB = rectY - slope * (rectX + rectWidth + offset) - offset;
  const maxB = rectY + rectHeight - slope * (rectX - offset) + offset;

  // 5. 绘制斜线条纹
  ctx.strokeStyle = stripeColor;
  ctx.lineWidth = 7;

  // 调整绘制顺序确保覆盖
  const startB = Math.min(minB, maxB);
  const endB = Math.max(minB, maxB);

  for (let b = startB; b <= endB; b += bStep) {
    ctx.beginPath();

    // 计算线段起点终点（考虑负斜率）
    const startX = rectX - offset;
    const startY = slope * startX + b;

    const endX = rectX + rectWidth + offset;
    const endY = slope * endX + b;

    ctx.moveTo(startX, startY);
    ctx.lineTo(endX, endY);
    ctx.stroke();
  }

  ctx.restore();
}

export const monitorNoRoomData = {
  name: "monitorNoRoom",
  width: 214,
  height: 140,
  borderRadius: 12,
};
